@@ -29,9 +29,9 @@ str(m.ibm2697)
 quantile(as.numeric(m.ibm2697))
 op <- par(mfrow=c(2,1))
 acf(m.ibm2697, ylim=c(-.2, .2), lag.max=100,
-    main="(a) Simple returns")
+    main="(a) Simple returns", acfLag0=FALSE)
 acf(log(1+m.ibm2697), ylim=c(-.2, .2), lag.max=100,
-    main="(b) Log returns")
+    main="(b) Log returns", acfLag0=FALSE)
 par(op)
 
 Box.test(m.ibm2697, 5, "Ljung-Box")
@@ -40,11 +40,11 @@ Box.test(m.ibm2697, 10, "Ljung-Box")
 Box.test(log(1+m.ibm2697), 5, "Ljung-Box")
 Box.test(log(1+m.ibm2697), 10, "Ljung-Box")
 
-autocorTest(m.ibm2697, 5)
-autocorTest(m.ibm2697, 10)
+AutocorTest(m.ibm2697, 5)
+AutocorTest(m.ibm2697, 10)
 
-autocorTest(log(1+m.ibm2697), 5)
-autocorTest(log(1+m.ibm2697), 10)
+AutocorTest(log(1+m.ibm2697), 5)
+AutocorTest(log(1+m.ibm2697), 10)
 
 # p. 29  
 # Figure 2.2.  Sample ACFs of monthly simple and log returns
@@ -52,9 +52,9 @@ autocorTest(log(1+m.ibm2697), 10)
 data(m.vw2697)
 op <- par(mfrow=c(2, 1))
 acf(m.vw2697, ylim=c(-.2, .2), lag.max=100,
-    main="(a) Simple returns")
+    main="(a) Simple returns", acfLag0=FALSE)
 acf(log(1+m.vw2697), ylim=c(-.2, .2), lag.max=100,
-    main="(b) Log returns")
+    main="(b) Log returns", acfLag0=FALSE)
 par(op)
 
 # R function in stats package 
@@ -65,11 +65,11 @@ Box.test(log(1+m.vw2697), 5, "Ljung-Box")
 Box.test(log(1+m.vw2697), 10, "Ljung-Box")
 
 # FinTS function in Tsay, p. 30 
-autocorTest(m.vw2697, 5)
-autocorTest(m.vw2697, 10)
+AutocorTest(m.vw2697, 5)
+AutocorTest(m.vw2697, 10)
 
-autocorTest(log(1+m.vw2697), 5)
-autocorTest(log(1+m.vw2697), 10)
+AutocorTest(log(1+m.vw2697), 5)
+AutocorTest(log(1+m.vw2697), 10)
 
 # p. 31
 ##
@@ -302,7 +302,7 @@ op <- par(mfrow=c(2,1))
 plot(m.ibmvwewsp2603[, "EW"], main="(a) Monthly simple returns",
      xlab="year", ylab="s-rtn")
 acf(as.numeric(m.ibmvwewsp2603[, "EW"]), ylim=c(-.4, .4),
-    main="(b) Sample ACF")
+    main="(b) Sample ACF", acfLag0=FALSE)
 par(op)
 
 # p. 54
@@ -347,11 +347,11 @@ plot(log(1+m.3m4697), xlab="year", ylab="l-rtn")
 acf(as.numeric(m.3m4697), main="")
 par(op)
 
-# What to do about EACF?
-# Question sent to Prof. Tsay 2007.12.01
-
-
-
+#eacf.3m <- eacf(m.3m4697, 6, 12) # 'eacf' function not yet available' 
+#print(eacf.3m, 2) 
+#print(eacf.3m) 
+# This may be due to differences in how the arima parameters
+# are estimated, e.g, maximum likelihood vs. Yule-Walker.  
 
 # p. 64 
 ##
@@ -480,20 +480,20 @@ par(op)
 # Figure 2.14.  
 op <- par(mfcol=c(2,2))
 acf(log(q.jnj))
-acf(diff(log(q.jnj)))
-acf(diff(log(q.jnj), 4))
+acf(diff(log(q.jnj)), main="Series:  dx")
+acf(diff(log(q.jnj), 4), main="Series:  ds")
 
 dxds <- diff(diff(log(q.jnj)), 4)
 dsdx <- diff(diff(log(q.jnj), 4))
 all.equal(dxds, dsdx)
 # TRUE 
-acf(dxds)
+acf(dxds, main="Series:  dxds")
 par(op)
 
 # p. 76
 # Example 2.3
 
-(fit.jnj <- arima(log(q.jnj), order=c(0, 1, 1),
+x(fit.jnj <- arima(log(q.jnj), order=c(0, 1, 1),
                  seasonal=list(order=c(0, 1, 1))))
 #str(fit.jnj)
 sqrt(fit.jnj$sigma2)
@@ -518,13 +518,14 @@ lines(exp(ll), col="red", lty="dashed")
 data(m.decile1510)
 str(m.decile1510)
 
+# p. 78
 op <- par(mfcol=c(2,2))
 
 plot(m.decile1510[,"Decile1"], xlab="year", ylab="s-rtn",
      main="(a) Simple returns")
 
 acf(as.numeric(m.decile1510[,"Decile1"]), lag.max=36,
-    main="(b) Sample ACF")
+    main="(b) Sample ACF", acfLag0=FALSE)
 
 #fit.dec1 <- arima(m.decile1510[, "Decile1"], c(1, 0, 0),
 #                  seasonal=list(order=c(1, 0, 1), period=12))
@@ -559,7 +560,6 @@ fit.dec1CSS
 sqrt(fit.dec1CSS$sigma2) 
 # Mostly match the conditional likelihood answers 
 
-# p. 78
 m.dec.index <- index(m.decile1510)
 str(m.dec.index)
 #Class 'Date'  num [1:528] -3625 -3594 -3563 -3534 -3502 ...
@@ -573,8 +573,7 @@ rtn.jan <- residuals(fitJan)
 plot(rtn.jan, xlab="year", ylab="rtn - jan",
      main="(c) January-adjusted returns")
 
-acf(as.numeric(rtn.jan), ylim=c(-.2, .3),
-    main="(d) Sample ACF")
+acf(as.numeric(rtn.jan), main="(d) Sample ACF", acfLag0=FALSE)
 
 par(op)
 
@@ -637,8 +636,8 @@ par(op)
 naiveResids.d.gs <- residuals(naiveFit.d.gs)
 
 op <- par(mfrow=c(2,1))
-plot(index(dw.gs1n3), naiveResids.d.gs, type="l"
-     xlab="year", ylab="residual", main="a")
+plot(index(dw.gs1n3), naiveResids.d.gs, type="l", 
+     xlab="year", ylab="residual", main="(a)")
 
 acf(naiveResids.d.gs, main="(b)")
 par(op)
@@ -663,7 +662,8 @@ fit.d.gs0$r.squared
 
 # p. 88
 library(lmtest)
-library(sandwich) 
+library(sandwich)
+
 coeftest(naiveFit.d.gs, vcovHC, type="HC1") 
 # 'type' = "HC1" uses (2.49), p. 87 
 # The default is "HC3".
@@ -674,7 +674,17 @@ coeftest(naiveFit.d.gs, vcovHC, type="HC1")
 
 coeftest(naiveFit.d.gs, NeweyWest)
 # t(gs1) = 38.3 vs. 40.1 in the book.
-# Close enough? 
+# Close enough?
+
+# For more information on 'coeftest', 'vcovHC', and 'NeweyWest', see
+# (sandw <- vignette("sandwich")) 
+# Stangle(sandw$file)
+#
+# and
+#
+# (swo <- vignette("sandwich-OOP"))
+# Stangle(swo$file) 
+
 
 # ARIMA fit:
 
@@ -696,3 +706,27 @@ summary(reg.ts)
 ## 2.11.  Long memory models
 ##
 
+# p. 90
+data(d.ibmvwewsp6203)
+str(d.ibmvwewsp6203)
+d.CRSP6297 <- window(d.ibmvwewsp6203, end=as.Date("1997-12-31"))
+dim(d.CRSP6297)
+# 8938 4
+abs.VW <- abs(d.CRSP6297[, "VW"])
+sum(is.na(abs.VW))
+# 0
+abs.VW. <- as.ts(abs.VW)
+str(abs.VW.)
+# 12966 obs ... 
+acf(as.numeric(abs.VW), lag.max=400, ylim=c(-.1, .4),
+    main="ACF of absolute returns of value-weighted index", acfLag0=FALSE)
+# Matches Figure 2.22(a) 
+acf(abs.VW, lag.max=400, ylim=c(-.1, .4), na.action=na.pass)
+# Different from Figure 2.22(a):
+# This assumes we have 365.24 days/year,
+# with NAs for weekends and holidays.
+# Figure 2.22(a) ignores weekends and holidays,
+# assuming that Monday follows Friday (except when there is a holiday).
+
+acf(as.numeric(abs(d.CRSP6297[, "EW"])), lag.max=400, ylim=c(-.1, .4),
+    main="ACF of absolute returns of equal-weighted index", acfLag0=FALSE)
